<?php
include_once(__DIR__."/database.php");
include_once(__DIR__."/../utils/encriptador.php");

function generarPassAleatorio($longitud) {
    $min = pow(10, $longitud - 1);
    $max = pow(10, $longitud) - 1;
    return random_int($min, $max);
}

function formatearFecha($fecha) {
  $date = new DateTime($fecha);
  $dia = $date->format('d');
  $mes = $date->format('M');
  $anio = $date->format('Y');
  
  return $dia . ' de ' . $mes . ' de ' . $anio;
}

function comprobar_inicio($id, $token) {
	$comprobacion = FALSE;
    $conn = Database::getInstance();
	$sql = "SELECT * FROM administrador_usuario_conexion WHERE administrador_usuario_conexion_idUsuario = :usuarioId AND administrador_usuario_conexion_token = :adminToken ";
	$stmt = $conn->prepare($sql);
	// Asignar los valores de entrada a los parámetros
	$stmt->bindParam(':usuarioId', $id);
	$stmt->bindParam(':adminToken', $token);

	$stmt->execute();
	$resultado = $stmt->fetch(PDO::FETCH_ASSOC);
	if ($resultado) {
		$comprobacion = $resultado['administrador_usuario_conexion_token'];
	}
	return $comprobacion;
}


function obtenCaracterAleatorio($arreglo) {
  $clave_aleatoria = array_rand($arreglo, 1);	//obtén clave aleatoria
  return $arreglo[ $clave_aleatoria ];	//devolver ítem aleatorio
}

function generarCodigo( $strength = 8) {
$permitted_chars = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
  $input_length = strlen($permitted_chars);

  $random_string = '';

  for($i = 0; $i < $strength; $i++) {

      $random_character = $permitted_chars[mt_rand(0, $input_length - 1)];

      $random_string .= $random_character;

  }

  return $random_string;

}

function obtenCaracterMd5($car) {
  $md5Car = md5($car.Time());	//Codificar el carácter y el tiempo POSIX (timestamp) en md5
  $arrCar = str_split(strtoupper($md5Car));	//Convertir a array el md5
  $carToken = obtenCaracterAleatorio($arrCar);	//obtén un ítem aleatoriamente
  return $carToken;
}

function obtenToken($longitud) {
  //crear alfabeto
  $mayus = "ABCDEFGHIJKMNPQRSTUVWXYZ";
  $mayusculas = str_split($mayus);	//Convertir a array
  //crear array de numeros 0-9
  $numeros = range(0,9);
  //revolver arrays
  shuffle($mayusculas);
  shuffle($numeros);
  //Unir arrays
  $arregloTotal = array_merge($mayusculas,$numeros);
  $newToken = "";
  
  for($i=0;$i<=$longitud;$i++) {
      $miCar = obtenCaracterAleatorio($arregloTotal);
      $newToken .= obtenCaracterMd5($miCar);
  }
  return $newToken;
}


function url_clean($String)
  {
    return str_replace('_',' ',$String); 
  }
function data_clean($str)
  {
      return str_replace(' ','_',$str);
  }
// Generar token CSRF único
function generateCSRFToken() {
  $token = bin2hex(random_bytes(32)); // Genera un token de 32 bytes en hexadecimal
  $_SESSION['csrf_token'] = $token; // Almacena el token en la sesión del usuario
  return $token;
}

// Verificar el token CSRF
function verifyCSRFToken($token) {
  if (isset($_SESSION['csrf_token']) && $token === $_SESSION['csrf_token']) {
      return true; // El token es válido
  }
  return false; // El token no es válido
}

function guardarHistorial($tipo, $usuario, $codigo,$cantidad){
	global $con; // Acceder a la variable de conexión global
	try {
		$consulta = mysqli_prepare($con, "INSERT INTO historial_productos (movimiento_historial_productos, usuario_historial_productos, codigo_historial_productos, cantidad_historial_productos) VALUES (?, ?, ?, ?)");

		if (!$consulta) {
			throw new Exception("Error al preparar la consulta");
		}
		// Vincular parámetros
		mysqli_stmt_bind_param($consulta, "sssi", $tipo, $usuario, $codigo, $cantidad);

		if (!mysqli_stmt_execute($consulta)) {
			throw new Exception("Error al ejecutar la consulta");
		}

		mysqli_stmt_close($consulta);
	} catch (Exception $e) {
		// Manejo de la excepción
		echo "Error: " . $e->getMessage();
	}
	
}



//------    CONVERTIR NUMEROS A LETRAS         ---------------
//------    Máxima cifra soportada: 18 dígitos con 2 decimales
//------    999,999,999,999,999,999.99
// NOVECIENTOS NOVENTA Y NUEVE MIL NOVECIENTOS NOVENTA Y NUEVE BILLONES
// NOVECIENTOS NOVENTA Y NUEVE MIL NOVECIENTOS NOVENTA Y NUEVE MILLONES
// NOVECIENTOS NOVENTA Y NUEVE MIL NOVECIENTOS NOVENTA Y NUEVE PESOS 99/100 M.N.
//------    Creada por:                        ---------------
//------             ULTIMINIO RAMOS GALÁN     ---------------
//------            uramos@gmail.com           ---------------
//------    10 de junio de 2009. México, D.F.  ---------------
//------    PHP Version 4.3.1 o mayores (aunque podría funcionar en versiones anteriores, tendrías que probar)
function numtoletras($xcifra)
{
    $xarray = array(0 => "Cero",
        1 => "UN", "DOS", "TRES", "CUATRO", "CINCO", "SEIS", "SIETE", "OCHO", "NUEVE",
        "DIEZ", "ONCE", "DOCE", "TRECE", "CATORCE", "QUINCE", "DIECISEIS", "DIECISIETE", "DIECIOCHO", "DIECINUEVE",
        "VEINTI", 30 => "TREINTA", 40 => "CUARENTA", 50 => "CINCUENTA", 60 => "SESENTA", 70 => "SETENTA", 80 => "OCHENTA", 90 => "NOVENTA",
        100 => "CIENTO", 200 => "DOSCIENTOS", 300 => "TRESCIENTOS", 400 => "CUATROCIENTOS", 500 => "QUINIENTOS", 600 => "SEISCIENTOS", 700 => "SETECIENTOS", 800 => "OCHOCIENTOS", 900 => "NOVECIENTOS"
    );
//
    $xcifra = trim($xcifra);
    $xlength = strlen($xcifra);
    $xpos_punto = strpos($xcifra, ".");
    $xaux_int = $xcifra;
    $xdecimales = "00";
    if (!($xpos_punto === false)) {
        if ($xpos_punto == 0) {
            $xcifra = "0" . $xcifra;
            $xpos_punto = strpos($xcifra, ".");
        }
        $xaux_int = substr($xcifra, 0, $xpos_punto); // obtengo el entero de la cifra a covertir
        $xdecimales = substr($xcifra . "00", $xpos_punto + 1, 2); // obtengo los valores decimales
    }

    $XAUX = str_pad($xaux_int, 18, " ", STR_PAD_LEFT); // ajusto la longitud de la cifra, para que sea divisible por centenas de miles (grupos de 6)
    $xcadena = "";
    for ($xz = 0; $xz < 3; $xz++) {
        $xaux = substr($XAUX, $xz * 6, 6);
        $xi = 0;
        $xlimite = 6; // inicializo el contador de centenas xi y establezco el límite a 6 dígitos en la parte entera
        $xexit = true; // bandera para controlar el ciclo del While
        while ($xexit) {
            if ($xi == $xlimite) { // si ya llegó al límite máximo de enteros
                break; // termina el ciclo
            }

            $x3digitos = ($xlimite - $xi) * -1; // comienzo con los tres primeros digitos de la cifra, comenzando por la izquierda
            $xaux = substr($xaux, $x3digitos, abs($x3digitos)); // obtengo la centena (los tres dígitos)
            for ($xy = 1; $xy < 4; $xy++) { // ciclo para revisar centenas, decenas y unidades, en ese orden
                switch ($xy) {
                    case 1: // checa las centenas
                        if (substr($xaux, 0, 3) < 100) { // si el grupo de tres dígitos es menor a una centena ( < 99) no hace nada y pasa a revisar las decenas
                            
                        } else {
                            $key = (int) substr($xaux, 0, 3);
                            if (TRUE === array_key_exists($key, $xarray)){  // busco si la centena es número redondo (100, 200, 300, 400, etc..)
                                $xseek = $xarray[$key];
                                $xsub = subfijo($xaux); // devuelve el subfijo correspondiente (Millón, Millones, Mil o nada)
                                if (substr($xaux, 0, 3) == 100)
                                    $xcadena = " " . $xcadena . " CIEN " . $xsub;
                                else
                                    $xcadena = " " . $xcadena . " " . $xseek . " " . $xsub;
                                $xy = 3; // la centena fue redonda, entonces termino el ciclo del for y ya no reviso decenas ni unidades
                            }
                            else { // entra aquí si la centena no fue numero redondo (101, 253, 120, 980, etc.)
                                $key = (int) substr($xaux, 0, 1) * 100;
                                $xseek = $xarray[$key]; // toma el primer caracter de la centena y lo multiplica por cien y lo busca en el arreglo (para que busque 100,200,300, etc)
                                $xcadena = " " . $xcadena . " " . $xseek;
                            } // ENDIF ($xseek)
                        } // ENDIF (substr($xaux, 0, 3) < 100)
                        break;
                    case 2: // checa las decenas (con la misma lógica que las centenas)
                        if (substr($xaux, 1, 2) < 10) {
                            
                        } else {
                            $key = (int) substr($xaux, 1, 2);
                            if (TRUE === array_key_exists($key, $xarray)) {
                                $xseek = $xarray[$key];
                                $xsub = subfijo($xaux);
                                if (substr($xaux, 1, 2) == 20)
                                    $xcadena = " " . $xcadena . " VEINTE " . $xsub;
                                else
                                    $xcadena = " " . $xcadena . " " . $xseek . " " . $xsub;
                                $xy = 3;
                            }
                            else {
                                $key = (int) substr($xaux, 1, 1) * 10;
                                $xseek = $xarray[$key];
                                if (20 == substr($xaux, 1, 1) * 10)
                                    $xcadena = " " . $xcadena . " " . $xseek;
                                else
                                    $xcadena = " " . $xcadena . " " . $xseek . " Y ";
                            } // ENDIF ($xseek)
                        } // ENDIF (substr($xaux, 1, 2) < 10)
                        break;
                    case 3: // checa las unidades
                        if (substr($xaux, 2, 1) < 1) { // si la unidad es cero, ya no hace nada
                            
                        } else {
                            $key = (int) substr($xaux, 2, 1);
                            $xseek = $xarray[$key]; // obtengo directamente el valor de la unidad (del uno al nueve)
                            $xsub = subfijo($xaux);
                            $xcadena = " " . $xcadena . " " . $xseek . " " . $xsub;
                        } // ENDIF (substr($xaux, 2, 1) < 1)
                        break;
                } // END SWITCH
            } // END FOR
            $xi = $xi + 3;
        } // ENDDO

        if (substr(trim($xcadena), -5, 5) == "ILLON") // si la cadena obtenida termina en MILLON o BILLON, entonces le agrega al final la conjuncion DE
            $xcadena.= " DE";

        if (substr(trim($xcadena), -7, 7) == "ILLONES") // si la cadena obtenida en MILLONES o BILLONES, entoncea le agrega al final la conjuncion DE
            $xcadena.= " DE";

        // ----------- esta línea la puedes cambiar de acuerdo a tus necesidades o a tu país -------
        if (trim($xaux) != "") {
            switch ($xz) {
                case 0:
                    if (trim(substr($XAUX, $xz * 6, 6)) == "1")
                        $xcadena.= "UN BILLON ";
                    else
                        $xcadena.= " BILLONES ";
                    break;
                case 1:
                    if (trim(substr($XAUX, $xz * 6, 6)) == "1")
                        $xcadena.= "UN MILLON ";
                    else
                        $xcadena.= " MILLONES ";
                    break;
                case 2:
                    if ($xcifra < 1) {
                        $xcadena = "CERO Guaranies";
                    }
                    if ($xcifra >= 1 && $xcifra < 2) {
                        $xcadena = "UN Guaranies";
                    }
                    if ($xcifra >= 2) {
                        $xcadena.= " Guaranies"; //
                    }
                    break;
            } // endswitch ($xz)
        } // ENDIF (trim($xaux) != "")
        // ------------------      en este caso, para México se usa esta leyenda     ----------------
        $xcadena = str_replace("VEINTI ", "VEINTI", $xcadena); // quito el espacio para el VEINTI, para que quede: VEINTICUATRO, VEINTIUN, VEINTIDOS, etc
        $xcadena = str_replace("  ", " ", $xcadena); // quito espacios dobles
        $xcadena = str_replace("UN UN", "UN", $xcadena); // quito la duplicidad
        $xcadena = str_replace("  ", " ", $xcadena); // quito espacios dobles
        $xcadena = str_replace("BILLON DE MILLONES", "BILLON DE", $xcadena); // corrigo la leyenda
        $xcadena = str_replace("BILLONES DE MILLONES", "BILLONES DE", $xcadena); // corrigo la leyenda
        $xcadena = str_replace("DE UN", "UN", $xcadena); // corrigo la leyenda
    } // ENDFOR ($xz)
    return trim($xcadena);
}

// END FUNCTION

function subfijo($xx)
{ // esta función regresa un subfijo para la cifra
    $xx = trim($xx);
    $xstrlen = strlen($xx);
    if ($xstrlen == 1 || $xstrlen == 2 || $xstrlen == 3)
        $xsub = "";
    //
    if ($xstrlen == 4 || $xstrlen == 5 || $xstrlen == 6)
        $xsub = "MIL";
    //
    return $xsub;
}

function verMarcas() {
    $comprobacion = FALSE;
    $conn = Database::getInstance();
    $sql = "SELECT * FROM vehiculo_marca";
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    $resultado = $stmt->fetchAll(PDO::FETCH_ASSOC);
    if ($resultado) {
        $comprobacion = $resultado; 
    }
    return $comprobacion;
}

function verMarca($id) {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM vehiculo_marca WHERE vehiculo_marca_id = :marcaId";
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':marcaId', $id, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function verModelosPorMarca($marcaId) {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM vehiculo_modelo WHERE vehiculo_modelo_marca = :marcaId"; 
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':marcaId', $marcaId, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}
function verActividades() {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM actividad_economica"; 
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC); 
}
function segurosHogar() {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_hogar"; 
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC); 
}
function segurosComercial() {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_comercio"; 
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC); 
}

function segurosRiesgos() {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_riesgo"; 
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC); 
}
function verPrefijos() {
    $conn = Database::getInstance();
    $sql = "SELECT * FROM prefijo"; 
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC); 
}
function generarCsrfToken()
{
    if (!isset($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = encrypt(session_id() . time());
    }
    return $_SESSION['csrf_token'];
}

function detallesPlanHogar($id){
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_hogar WHERE seguro_hogar_id = :id"; 
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}
function detallesPlanComercio($id){
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_comercio WHERE seguro_comercio_id = :id"; 
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}
function detallesPlanVida($id){
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_vida WHERE seguro_vida_id = :id"; 
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}
function selectorPlanVida($edad){
    $conn = Database::getInstance();
    $sql = "SELECT * FROM seguro_vida WHERE seguro_vida_edad_rango = :edad"; 
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':edad', $edad, PDO::PARAM_INT);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}
// END FUNCTIONES
?>